@@ -25,8 +25,14 @@
  *
  */
 
+#if !defined(__ASOUNDLIB_H) && !defined(ALSA_LIBRARY_BUILD)
+/* don't use ALSA_LIBRARY_BUILD define in sources outside alsa-lib */
+#warning "use #include <alsa/asoundlib.h>, <alsa/control.h> should not be used directly"
+#include <alsa/asoundlib.h>
+#endif
+
 #ifndef __ALSA_CONTROL_H
-#define __ALSA_CONTROL_H
+#define __ALSA_CONTROL_H /**< header include loop protection */
 
 #ifdef __cplusplus
 extern "C" {
@@ -380,7 +386,7 @@ int snd_ctl_open_fallback(snd_ctl_t **ctl, snd_config_t *root, const char *name,
 int snd_ctl_close(snd_ctl_t *ctl);
 int snd_ctl_nonblock(snd_ctl_t *ctl, int nonblock);
 static __inline__ int snd_ctl_abort(snd_ctl_t *ctl) { return snd_ctl_nonblock(ctl, 2); }
-int snd_async_add_ctl_handler(snd_async_handler_t **handler, snd_ctl_t *ctl, 
+int snd_async_add_ctl_handler(snd_async_handler_t **handler, snd_ctl_t *ctl,
 			      snd_async_callback_t callback, void *private_data);
 snd_ctl_t *snd_async_handler_get_ctl(snd_async_handler_t *handler);
 int snd_ctl_poll_descriptors_count(snd_ctl_t *ctl);
@@ -712,7 +718,7 @@ typedef int (*snd_hctl_compare_t)(const snd_hctl_elem_t *e1,
 				  const snd_hctl_elem_t *e2);
 int snd_hctl_compare_fast(const snd_hctl_elem_t *c1,
 			  const snd_hctl_elem_t *c2);
-/** 
+/**
  * \brief HCTL callback function
  * \param hctl HCTL handle
  * \param mask event mask
@@ -722,7 +728,7 @@ int snd_hctl_compare_fast(const snd_hctl_elem_t *c1,
 typedef int (*snd_hctl_callback_t)(snd_hctl_t *hctl,
 				   unsigned int mask,
 				   snd_hctl_elem_t *elem);
-/** 
+/**
  * \brief HCTL element callback function
  * \param elem HCTL element
  * \param mask event mask
