@@ -274,13 +274,8 @@ size_t snd_strlcat(char *dst, const char *src, size_t size);
  */
 #ifndef NDEBUG
 #define CHECK_SANITY(x) x
-extern snd_lib_error_handler_t snd_err_msg;
-#define SNDMSG(args...) snd_err_msg(__FILE__, __LINE__, __func__, 0, ##args)
-#define SYSMSG(args...) snd_err_msg(__FILE__, __LINE__, __func__, errno, ##args)
 #else
 #define CHECK_SANITY(x) 0 /* not evaluated */
-#define SNDMSG(args...) /* nop */
-#define SYSMSG(args...) /* nop */
 #endif
 
 /*
@@ -386,7 +381,7 @@ int snd_config_check_hop(snd_config_t *conf);
 #define SND_CONF_MAX_HOPS	64
 
 int snd_config_search_alias_hooks(snd_config_t *config,
-                                  const char *base, const char *key,
+				  const char *base, const char *key,
 				  snd_config_t **result);
 
 int _snd_conf_generic_id(const char *id);
