@@ -18,7 +18,7 @@
  *
  */
 
-#include "config.h"
+#include "pcm_local.h"
 #include <stdio.h>
 #if HAVE_MALLOC_H
 #include <malloc.h>
@@ -29,7 +29,6 @@
 #ifdef HAVE_SYS_SHM_H
 #include <sys/shm.h>
 #endif
-#include "pcm_local.h"
 
 void snd_pcm_mmap_appl_backward(snd_pcm_t *pcm, snd_pcm_uframes_t frames)
 {
@@ -75,7 +74,7 @@ static snd_pcm_sframes_t snd_pcm_mmap_write_areas(snd_pcm_t *pcm,
 	snd_pcm_uframes_t xfer = 0;
 
 	if (snd_pcm_mmap_playback_avail(pcm) < size) {
-		SNDMSG("too short avail %ld to size %ld", snd_pcm_mmap_playback_avail(pcm), size);
+		snd_check(PCM, "too short avail %ld to size %ld", snd_pcm_mmap_playback_avail(pcm), size);
 		return -EPIPE;
 	}
 	while (size > 0) {
@@ -86,8 +85,8 @@ static snd_pcm_sframes_t snd_pcm_mmap_write_areas(snd_pcm_t *pcm,
 
 		__snd_pcm_mmap_begin(pcm, &pcm_areas, &pcm_offset, &frames);
 		snd_pcm_areas_copy(pcm_areas, pcm_offset,
-				   areas, offset, 
-				   pcm->channels, 
+				   areas, offset,
+				   pcm->channels,
 				   frames, pcm->format);
 		result = __snd_pcm_mmap_commit(pcm, pcm_offset, frames);
 		if (result < 0)
@@ -107,7 +106,7 @@ static snd_pcm_sframes_t snd_pcm_mmap_read_areas(snd_pcm_t *pcm,
 	snd_pcm_uframes_t xfer = 0;
 
 	if (snd_pcm_mmap_capture_avail(pcm) < size) {
-		SNDMSG("too short avail %ld to size %ld", snd_pcm_mmap_capture_avail(pcm), size);
+		snd_check(PCM, "too short avail %ld to size %ld", snd_pcm_mmap_capture_avail(pcm), size);
 		return -EPIPE;
 	}
 	while (size > 0) {
@@ -115,11 +114,11 @@ static snd_pcm_sframes_t snd_pcm_mmap_read_areas(snd_pcm_t *pcm,
 		snd_pcm_uframes_t pcm_offset;
 		snd_pcm_uframes_t frames = size;
 		snd_pcm_sframes_t result;
-		
+
 		__snd_pcm_mmap_begin(pcm, &pcm_areas, &pcm_offset, &frames);
 		snd_pcm_areas_copy(areas, offset,
 				   pcm_areas, pcm_offset,
-				   pcm->channels, 
+				   pcm->channels,
 				   frames, pcm->format);
 		result = __snd_pcm_mmap_commit(pcm, pcm_offset, frames);
 		if (result < 0)
@@ -245,7 +244,7 @@ int snd_pcm_channel_info_shm(snd_pcm_t *pcm, snd_pcm_channel_info_t *info, int s
 		info->step = pcm->sample_bits;
 		break;
 	default:
-		SNDMSG("invalid access type %d", pcm->access);
+		snd_check(PCM, "invalid access type %d", pcm->access);
 		return -EINVAL;
 	}
 	info->addr = 0;
@@ -256,7 +255,7 @@ int snd_pcm_channel_info_shm(snd_pcm_t *pcm, snd_pcm_channel_info_t *info, int s
 	} else
 		info->type = SND_PCM_AREA_LOCAL;
 	return 0;
-}	
+}
 
 int snd_pcm_mmap(snd_pcm_t *pcm)
 {
@@ -264,11 +263,11 @@ int snd_pcm_mmap(snd_pcm_t *pcm)
 	unsigned int c;
 	assert(pcm);
 	if (CHECK_SANITY(! pcm->setup)) {
-		SNDMSG("PCM not set up");
+		snd_check(PCM, "PCM not set up");
 		return -EIO;
 	}
 	if (CHECK_SANITY(pcm->mmap_channels || pcm->running_areas)) {
-		SNDMSG("Already mmapped");
+		snd_check(PCM, "Already mmapped");
 		return -EBUSY;
 	}
 	if (pcm->ops->mmap)
@@ -307,12 +306,12 @@ int snd_pcm_mmap(snd_pcm_t *pcm)
 		size_t size;
 		unsigned int c1;
 		if (i->addr) {
-        		a->addr = i->addr;
-        		a->first = i->first;
-        		a->step = i->step;
-		        continue;
-                }
-                size = i->first + i->step * (pcm->buffer_size - 1) + pcm->sample_bits;
+			a->addr = i->addr;
+			a->first = i->first;
+			a->step = i->step;
+			continue;
+		}
+		size = i->first + i->step * (pcm->buffer_size - 1) + pcm->sample_bits;
 		for (c1 = c + 1; c1 < pcm->channels; ++c1) {
 			snd_pcm_channel_info_t *i1 = &pcm->mmap_channels[c1];
 			size_t s;
@@ -343,7 +342,7 @@ int snd_pcm_mmap(snd_pcm_t *pcm)
 		case SND_PCM_AREA_MMAP:
 			ptr = mmap(NULL, size, PROT_READ|PROT_WRITE, MAP_FILE|MAP_SHARED, i->u.mmap.fd, i->u.mmap.offset);
 			if (ptr == MAP_FAILED) {
-				SYSERR("mmap failed");
+				snd_errornum(PCM, "mmap failed");
 				return -errno;
 			}
 			i->addr = ptr;
@@ -355,23 +354,23 @@ int snd_pcm_mmap(snd_pcm_t *pcm)
 				/* FIXME: safer permission? */
 				id = shmget(IPC_PRIVATE, size, 0666);
 				if (id < 0) {
-					SYSERR("shmget failed");
+					snd_errornum(PCM, "shmget failed");
 					return -errno;
 				}
 				i->u.shm.shmid = id;
 				ptr = shmat(i->u.shm.shmid, 0, 0);
 				if (ptr == (void *) -1) {
-					SYSERR("shmat failed");
+					snd_errornum(PCM, "shmat failed");
 					return -errno;
 				}
 				/* automatically remove segment if not used */
 				if (shmctl(id, IPC_RMID, NULL) < 0){
-					SYSERR("shmctl mark remove failed");
+					snd_errornum(PCM, "shmctl mark remove failed");
 					return -errno;
 				}
 				i->u.shm.area = snd_shm_area_create(id, ptr);
 				if (i->u.shm.area == NULL) {
-					SYSERR("snd_shm_area_create failed");
+					snd_errornum(PCM, "snd_shm_area_create failed");
 					return -ENOMEM;
 				}
 				if (pcm->access == SND_PCM_ACCESS_MMAP_INTERLEAVED ||
@@ -388,20 +387,20 @@ int snd_pcm_mmap(snd_pcm_t *pcm)
 			} else {
 				ptr = shmat(i->u.shm.shmid, 0, 0);
 				if (ptr == (void*) -1) {
-					SYSERR("shmat failed");
+					snd_errornum(PCM, "shmat failed");
 					return -errno;
 				}
 			}
 			i->addr = ptr;
 			break;
 #else
-			SYSERR("shm support not available");
+			snd_errornum(PCM, "shm support not available");
 			return -ENOSYS;
 #endif
 		case SND_PCM_AREA_LOCAL:
 			ptr = malloc(size);
 			if (ptr == NULL) {
-				SYSERR("malloc failed");
+				snd_errornum(PCM, "malloc failed");
 				return -errno;
 			}
 			i->addr = ptr;
@@ -416,7 +415,7 @@ int snd_pcm_mmap(snd_pcm_t *pcm)
 			switch (i1->type) {
 			case SND_PCM_AREA_MMAP:
 				if (i1->u.mmap.fd != i->u.mmap.fd ||
-                                    i1->u.mmap.offset != i->u.mmap.offset)
+				    i1->u.mmap.offset != i->u.mmap.offset)
 					continue;
 				break;
 			case SND_PCM_AREA_SHM:
@@ -426,7 +425,7 @@ int snd_pcm_mmap(snd_pcm_t *pcm)
 			case SND_PCM_AREA_LOCAL:
 				if (pcm->access != SND_PCM_ACCESS_MMAP_INTERLEAVED &&
 				    pcm->access != SND_PCM_ACCESS_RW_INTERLEAVED)
-				        continue;
+					continue;
 				break;
 			default:
 				assert(0);
@@ -446,7 +445,7 @@ int snd_pcm_munmap(snd_pcm_t *pcm)
 	unsigned int c;
 	assert(pcm);
 	if (CHECK_SANITY(! pcm->mmap_channels)) {
-		SNDMSG("Not mmapped");
+		snd_check(PCM, "Not mmapped");
 		return -ENXIO;
 	}
 	if (pcm->mmap_shadow) {
@@ -477,7 +476,7 @@ int snd_pcm_munmap(snd_pcm_t *pcm)
 		case SND_PCM_AREA_MMAP:
 			err = munmap(i->addr, size);
 			if (err < 0) {
-				SYSERR("mmap failed");
+				snd_errornum(PCM, "mmap failed");
 				return -errno;
 			}
 			errno = 0;
@@ -501,7 +500,7 @@ int snd_pcm_munmap(snd_pcm_t *pcm)
 			}
 			break;
 #else
-			SYSERR("shm support not available");
+			snd_errornum(PCM, "shm support not available");
 			return -ENOSYS;
 #endif
 		case SND_PCM_AREA_LOCAL:
@@ -568,7 +567,7 @@ snd_pcm_sframes_t snd_pcm_write_mmap(snd_pcm_t *pcm, snd_pcm_uframes_t offset,
 			break;
 		}
 		default:
-			SNDMSG("invalid access type %d", pcm->access);
+			snd_check(PCM, "invalid access type %d", pcm->access);
 			return -EINVAL;
 		}
 		if (err < 0)
@@ -624,7 +623,7 @@ snd_pcm_sframes_t snd_pcm_read_mmap(snd_pcm_t *pcm, snd_pcm_uframes_t offset,
 			break;
 		}
 		default:
-			SNDMSG("invalid access type %d", pcm->access);
+			snd_check(PCM, "invalid access type %d", pcm->access);
 			return -EINVAL;
 		}
 		if (err < 0)
