@@ -25,14 +25,14 @@
  *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
-  
+
+#include "pcm_local.h"
+#include "pcm_generic.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
 #include <math.h>
-#include "pcm_local.h"
-#include "pcm_generic.h"
 
 #ifndef PIC
 /* entry for static linking */
@@ -208,7 +208,7 @@ static int snd_pcm_multi_hw_refine_schange(snd_pcm_t *pcm ATTRIBUTE_UNUSED,
 		return err;
 	return 0;
 }
-	
+
 static int snd_pcm_multi_hw_refine_cchange(snd_pcm_t *pcm ATTRIBUTE_UNUSED,
 					   unsigned int slave_idx ATTRIBUTE_UNUSED,
 					   snd_pcm_hw_params_t *params,
@@ -266,7 +266,7 @@ static int snd_pcm_multi_hw_refine(snd_pcm_t *pcm, snd_pcm_hw_params_t *params)
 	for (k = 0; k < multi->slaves_count; ++k) {
 		err = snd_pcm_multi_hw_refine_sprepare(pcm, k, &sparams[k]);
 		if (err < 0) {
-			SNDERR("Slave PCM #%d not usable", k);
+			snd_error(PCM, "Slave PCM #%d not usable", k);
 			return err;
 		}
 	}
@@ -523,7 +523,7 @@ static int snd_pcm_multi_reset(snd_pcm_t *pcm)
 	for (i = 0; i < multi->slaves_count; ++i) {
 		/* Reset each slave, as well as in prepare */
 		err = snd_pcm_reset(multi->slaves[i].pcm);
-		if (err < 0) 
+		if (err < 0)
 			result = err;
 	}
 	multi->hw_ptr = multi->appl_ptr = 0;
@@ -735,7 +735,7 @@ static int snd_pcm_multi_resume(snd_pcm_t *pcm)
  * including the first one has to be relinked to the given master.
  */
 static int snd_pcm_multi_link_slaves(snd_pcm_t *pcm, snd_pcm_t *master)
-{ 
+{
 	snd_pcm_multi_t *multi = pcm->private_data;
 	unsigned int i;
 	int err;
@@ -993,7 +993,7 @@ static void snd_pcm_multi_dump(snd_pcm_t *pcm, snd_output_t *out)
 		snd_pcm_multi_channel_t *c = &multi->channels[k];
 		if (c->slave_idx < 0)
 			continue;
-		snd_output_printf(out, "    %d: slave %d, channel %d\n", 
+		snd_output_printf(out, "    %d: slave %d, channel %d\n",
 			k, c->slave_idx, c->slave_channel);
 	}
 	if (pcm->setup) {
@@ -1097,7 +1097,7 @@ int snd_pcm_multi_open(snd_pcm_t **pcmp, const char *name,
 	}
 
 	stream = slaves_pcm[0]->stream;
-	
+
 	multi->slaves_count = slaves_count;
 	multi->master_slave = master_slave;
 	multi->slaves = calloc(slaves_count, sizeof(*multi->slaves));
@@ -1160,8 +1160,8 @@ This plugin converts multiple streams to one.
 
 \code
 pcm.name {
-        type multi              # Multiple streams conversion PCM
-        slaves {		# Slaves definition
+	type multi              # Multiple streams conversion PCM
+	slaves {		# Slaves definition
 		ID STR		# Slave PCM name
 		# or
 		ID {
@@ -1170,7 +1170,7 @@ pcm.name {
 			pcm { } 	# Slave PCM definition
 			channels INT	# Slave channels
 		}
-        }
+	}
 	bindings {		# Bindings table
 		N {
 			slave STR	# Slave key
@@ -1267,7 +1267,7 @@ int _snd_pcm_multi_open(snd_pcm_t **pcmp, const char *name,
 			continue;
 		if (strcmp(id, "slaves") == 0) {
 			if (snd_config_get_type(n) != SND_CONFIG_TYPE_COMPOUND) {
-				SNDERR("Invalid type for %s", id);
+				snd_error(PCM, "Invalid type for %s", id);
 				return -EINVAL;
 			}
 			slaves = n;
@@ -1275,7 +1275,7 @@ int _snd_pcm_multi_open(snd_pcm_t **pcmp, const char *name,
 		}
 		if (strcmp(id, "bindings") == 0) {
 			if (snd_config_get_type(n) != SND_CONFIG_TYPE_COMPOUND) {
-				SNDERR("Invalid type for %s", id);
+				snd_error(PCM, "Invalid type for %s", id);
 				return -EINVAL;
 			}
 			bindings = n;
@@ -1283,27 +1283,27 @@ int _snd_pcm_multi_open(snd_pcm_t **pcmp, const char *name,
 		}
 		if (strcmp(id, "master") == 0) {
 			if (snd_config_get_integer(n, &master_slave) < 0) {
-				SNDERR("Invalid type for %s", id);
+				snd_error(PCM, "Invalid type for %s", id);
 				return -EINVAL;
 			}
 			continue;
 		}
-		SNDERR("Unknown field %s", id);
+		snd_error(PCM, "Unknown field %s", id);
 		return -EINVAL;
 	}
 	if (!slaves) {
-		SNDERR("slaves is not defined");
+		snd_error(PCM, "slaves is not defined");
 		return -EINVAL;
 	}
 	if (!bindings) {
-		SNDERR("bindings is not defined");
+		snd_error(PCM, "bindings is not defined");
 		return -EINVAL;
 	}
 	snd_config_for_each(i, inext, slaves) {
 		++slaves_count;
 	}
 	if (master_slave < 0 || master_slave >= (long)slaves_count) {
-		SNDERR("Master slave is out of range (0-%u)\n", slaves_count-1);
+		snd_error(PCM, "Master slave is out of range (0-%u)", slaves_count-1);
 		return -EINVAL;
 	}
 	snd_config_for_each(i, inext, bindings) {
@@ -1314,14 +1314,14 @@ int _snd_pcm_multi_open(snd_pcm_t **pcmp, const char *name,
 			continue;
 		err = safe_strtol(id, &cchannel);
 		if (err < 0 || cchannel < 0) {
-			SNDERR("Invalid channel number: %s", id);
+			snd_error(PCM, "Invalid channel number: %s", id);
 			return -EINVAL;
 		}
 		if ((unsigned long)cchannel >= channels_count)
 			channels_count = cchannel + 1;
 	}
 	if (channels_count == 0) {
-		SNDERR("No channels defined");
+		snd_error(PCM, "No channels defined");
 		return -EINVAL;
 	}
 	slaves_id = calloc(slaves_count, sizeof(*slaves_id));
@@ -1365,7 +1365,7 @@ int _snd_pcm_multi_open(snd_pcm_t **pcmp, const char *name,
 			continue;
 		err = safe_strtol(id, &cchannel);
 		if (err < 0 || cchannel < 0) {
-			SNDERR("Invalid channel number: %s", id);
+			snd_error(PCM, "Invalid channel number: %s", id);
 			err = -EINVAL;
 			goto _free;
 		}
@@ -1383,7 +1383,7 @@ int _snd_pcm_multi_open(snd_pcm_t **pcmp, const char *name,
 				if (err < 0) {
 					err = snd_config_get_integer(n, &val);
 					if (err < 0) {
-						SNDERR("Invalid value for %s", id);
+						snd_error(PCM, "Invalid value for %s", id);
 						goto _free;
 					}
 					sprintf(buf, "%ld", val);
@@ -1398,30 +1398,30 @@ int _snd_pcm_multi_open(snd_pcm_t **pcmp, const char *name,
 			if (strcmp(id, "channel") == 0) {
 				err = snd_config_get_integer(n, &schannel);
 				if (err < 0) {
-					SNDERR("Invalid type for %s", id);
+					snd_error(PCM, "Invalid type for %s", id);
 					goto _free;
 				}
 				continue;
 			}
-			SNDERR("Unknown field %s", id);
+			snd_error(PCM, "Unknown field %s", id);
 			err = -EINVAL;
 			goto _free;
 		}
 		if (slave < 0 || (unsigned int)slave >= slaves_count) {
-			SNDERR("Invalid or missing sidx for channel %s", id);
+			snd_error(PCM, "Invalid or missing sidx for channel %s", id);
 			err = -EINVAL;
 			goto _free;
 		}
-		if (schannel < 0 || 
+		if (schannel < 0 ||
 		    (unsigned int) schannel >= slaves_channels[slave]) {
-			SNDERR("Invalid or missing schannel for channel %s", id);
+			snd_error(PCM, "Invalid or missing schannel for channel %s", id);
 			err = -EINVAL;
 			goto _free;
 		}
 		channels_sidx[cchannel] = slave;
 		channels_schannel[cchannel] = schannel;
 	}
-	
+
 	for (idx = 0; idx < slaves_count; ++idx) {
 		err = snd_pcm_open_slave(&slaves_pcm[idx], root,
 					 slaves_conf[idx], stream, mode,
@@ -1439,13 +1439,13 @@ int _snd_pcm_multi_open(snd_pcm_t **pcmp, const char *name,
 _free:
 	if (err < 0) {
 		for (idx = 0; idx < slaves_count; ++idx) {
-			if (slaves_pcm[idx])
+			if (slaves_pcm && slaves_pcm[idx])
 				snd_pcm_close(slaves_pcm[idx]);
 		}
 	}
 	if (slaves_conf) {
 		for (idx = 0; idx < slaves_count; ++idx) {
-			if (slaves_conf[idx])
+			if (slaves_conf && slaves_conf[idx])
 				snd_config_delete(slaves_conf[idx]);
 		}
 		free(slaves_conf);
