@@ -25,7 +25,8 @@
  *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
-  
+
+#include "pcm_local.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <limits.h>
@@ -36,7 +37,6 @@
 #include <sys/socket.h>
 #include <poll.h>
 #include <pthread.h>
-#include "pcm_local.h"
 
 #ifndef PIC
 /* entry for static linking */
@@ -122,7 +122,7 @@ static snd_pcm_uframes_t snd_pcm_share_slave_avail(snd_pcm_share_slave_t *slave)
 {
 	snd_pcm_sframes_t avail;
 	snd_pcm_t *pcm = slave->pcm;
-  	avail = slave->hw_ptr - *pcm->appl.ptr;
+	avail = slave->hw_ptr - *pcm->appl.ptr;
 	if (pcm->stream == SND_PCM_STREAM_PLAYBACK)
 		avail += pcm->buffer_size;
 	if (avail < 0)
@@ -188,7 +188,7 @@ static snd_pcm_uframes_t _snd_pcm_share_slave_forward(snd_pcm_share_slave_t *sla
 }
 
 
-/* 
+/*
    - stop PCM on xrun
    - update poll status
    - draining silencing
@@ -205,6 +205,7 @@ static snd_pcm_uframes_t _snd_pcm_share_missing(snd_pcm_t *pcm)
 	snd_pcm_sframes_t hw_avail;
 	snd_pcm_uframes_t missing = INT_MAX;
 	snd_pcm_sframes_t ready_missing;
+	ssize_t s;
 	// printf("state=%s hw_ptr=%ld appl_ptr=%ld slave appl_ptr=%ld safety=%ld silence=%ld\n", snd_pcm_state_name(share->state), slave->hw_ptr, share->appl_ptr, *slave->pcm->appl_ptr, slave->safety_threshold, slave->silence_frames);
 	switch (share->state) {
 	case SND_PCM_STATE_RUNNING:
@@ -237,11 +238,11 @@ static snd_pcm_uframes_t _snd_pcm_share_missing(snd_pcm_t *pcm)
 			}
 			err = snd_pcm_mmap_commit(spcm, snd_pcm_mmap_offset(spcm), frames);
 			if (err < 0) {
-				SYSMSG("snd_pcm_mmap_commit error");
+				snd_checknum(PCM, "snd_pcm_mmap_commit error");
 				return INT_MAX;
 			}
 			if (err != frames)
-				SYSMSG("commit returns %ld for size %ld", err, frames);
+				snd_checknum(PCM, "commit returns %ld for size %ld", err, frames);
 			slave_avail -= err;
 		} else {
 			if (safety_missing == 0)
@@ -281,23 +282,31 @@ static snd_pcm_uframes_t _snd_pcm_share_missing(snd_pcm_t *pcm)
 		running = 1;
 		break;
 	default:
-		SNDERR("invalid shared PCM state %d", share->state);
+		snd_error(PCM, "invalid shared PCM state %d", share->state);
 		return INT_MAX;
 	}
 
  update_poll:
 	if (ready != share->ready) {
-		char buf[1];
-		if (pcm->stream == SND_PCM_STREAM_PLAYBACK) {
-			if (ready)
-				read(share->slave_socket, buf, 1);
-			else
-				write(share->client_socket, buf, 1);
-		} else {
-			if (ready)
-				write(share->slave_socket, buf, 1);
-			else
-				read(share->client_socket, buf, 1);
+		char buf[1] = {0};
+		while (1) {
+			if (pcm->stream == SND_PCM_STREAM_PLAYBACK) {
+				if (ready)
+					s = read(share->slave_socket, buf, 1);
+				else
+					s = write(share->client_socket, buf, 1);
+			} else {
+				if (ready)
+					s = write(share->slave_socket, buf, 1);
+				else
+					s = read(share->client_socket, buf, 1);
+			}
+			if (s < 0) {
+				if (errno == EINTR)
+					continue;
+				return INT_MAX;
+			}
+			break;
 		}
 		share->ready = ready;
 	}
@@ -357,17 +366,18 @@ static void *snd_pcm_share_thread(void *data)
 	struct pollfd pfd[2];
 	int err;
 
+	Pthread_mutex_lock(&slave->mutex);
 	pfd[0].fd = slave->poll[0];
 	pfd[0].events = POLLIN;
 	err = snd_pcm_poll_descriptors(spcm, &pfd[1], 1);
 	if (err != 1) {
-		SNDERR("invalid poll descriptors %d", err);
+		snd_error(PCM, "invalid poll descriptors %d", err);
+		Pthread_mutex_unlock(&slave->mutex);
 		return NULL;
 	}
-	Pthread_mutex_lock(&slave->mutex);
 	err = pipe(slave->poll);
 	if (err < 0) {
-		SYSERR("can't create a pipe");
+		snd_errornum(PCM, "can't create a pipe");
 		Pthread_mutex_unlock(&slave->mutex);
 		return NULL;
 	}
@@ -394,7 +404,7 @@ static void *snd_pcm_share_thread(void *data)
 				snd_pcm_sw_params_set_avail_min(spcm, &slave->sw_params, avail_min);
 				err = snd_pcm_sw_params(spcm, &slave->sw_params);
 				if (err < 0) {
-					SYSERR("snd_pcm_sw_params error");
+					snd_errornum(PCM, "snd_pcm_sw_params error");
 					Pthread_mutex_unlock(&slave->mutex);
 					return NULL;
 				}
@@ -403,9 +413,9 @@ static void *snd_pcm_share_thread(void *data)
 			Pthread_mutex_unlock(&slave->mutex);
 			err = poll(pfd, 2, -1);
 			Pthread_mutex_lock(&slave->mutex);
-			if (pfd[0].revents & POLLIN) {
+			if (err > 0 && (pfd[0].revents & POLLIN) != 0) {
 				char buf[1];
-				read(pfd[0].fd, buf, 1);
+				(void)read(pfd[0].fd, buf, 1);
 			}
 		} else {
 			slave->polling = 0;
@@ -448,7 +458,7 @@ static void _snd_pcm_share_update(snd_pcm_t *pcm)
 			snd_pcm_sw_params_set_avail_min(spcm, &slave->sw_params, avail_min);
 			err = snd_pcm_sw_params(spcm, &slave->sw_params);
 			if (err < 0) {
-				SYSERR("snd_pcm_sw_params error");
+				snd_errornum(PCM, "snd_pcm_sw_params error");
 				return;
 			}
 		}
@@ -557,7 +567,7 @@ static int snd_pcm_share_hw_refine_schange(snd_pcm_t *pcm ATTRIBUTE_UNUSED, snd_
 		return err;
 	return 0;
 }
-	
+
 static int snd_pcm_share_hw_refine_cchange(snd_pcm_t *pcm ATTRIBUTE_UNUSED, snd_pcm_hw_params_t *params,
 					   snd_pcm_hw_params_t *sparams)
 {
@@ -626,7 +636,7 @@ static int snd_pcm_share_hw_params(snd_pcm_t *pcm, snd_pcm_hw_params_t *params)
 		if (err < 0)
 			goto _err;
 		err = _snd_pcm_hw_param_set_minmax(params, SND_PCM_HW_PARAM_RATE,
-						   spcm->rate, 0, 
+						   spcm->rate, 0,
 						   spcm->rate, 1);
 		if (err < 0)
 			goto _err;
@@ -639,7 +649,7 @@ static int snd_pcm_share_hw_params(snd_pcm_t *pcm, snd_pcm_hw_params_t *params)
 					    spcm->buffer_size, 0);
 	_err:
 		if (err < 0) {
-			SNDERR("slave is already running with incompatible setup");
+			snd_error(PCM, "slave is already running with incompatible setup");
 			err = -EBUSY;
 			goto _end;
 		}
@@ -711,6 +721,8 @@ static int snd_pcm_share_status(snd_pcm_t *pcm, snd_pcm_status_t *status)
  _notrunning:
 	status->delay = sd + d;
 	status->state = share->state;
+	status->appl_ptr = *pcm->appl.ptr;
+	status->hw_ptr = *pcm->hw.ptr;
 	status->trigger_tstamp = share->trigger_tstamp;
  _end:
 	Pthread_mutex_unlock(&slave->mutex);
@@ -841,11 +853,11 @@ static snd_pcm_sframes_t _snd_pcm_share_mmap_commit(snd_pcm_t *pcm,
 			snd_pcm_sframes_t err;
 			err = snd_pcm_mmap_commit(spcm, snd_pcm_mmap_offset(spcm), frames);
 			if (err < 0) {
-				SYSMSG("snd_pcm_mmap_commit error");
+				snd_checknum(PCM, "snd_pcm_mmap_commit error");
 				return err;
 			}
 			if (err != frames) {
-				SYSMSG("commit returns %ld for size %ld", err, frames);
+				snd_checknum(PCM, "commit returns %ld for size %ld", err, frames);
 				return err;
 			}
 		}
@@ -920,9 +932,12 @@ static int snd_pcm_share_start(snd_pcm_t *pcm)
 	snd_pcm_share_slave_t *slave = share->slave;
 	snd_pcm_t *spcm = slave->pcm;
 	int err = 0;
-	if (share->state != SND_PCM_STATE_PREPARED)
-		return -EBADFD;
+
 	Pthread_mutex_lock(&slave->mutex);
+	if (share->state != SND_PCM_STATE_PREPARED) {
+		err = -EBADFD;
+		goto _end;
+	}
 	share->state = SND_PCM_STATE_RUNNING;
 	if (pcm->stream == SND_PCM_STREAM_PLAYBACK) {
 		snd_pcm_uframes_t hw_avail = snd_pcm_mmap_playback_hw_avail(pcm);
@@ -1141,8 +1156,13 @@ static void _snd_pcm_share_stop(snd_pcm_t *pcm, snd_pcm_state_t state)
 		snd_pcm_areas_silence(pcm->running_areas, 0, pcm->channels,
 				      pcm->buffer_size, pcm->format);
 		err = snd_pcm_delay(slave->pcm, &delay);
-		if (err >= 0 && delay > 0)
-			snd_pcm_rewind(slave->pcm, delay);
+		if (err >= 0 && delay > 0) {
+			int err = snd_pcm_rewind(slave->pcm, delay);
+			if (err < 0) {
+				errno = -err;
+				snd_errornum(PCM, "rewind failed");
+			}
+		}
 		share->drain_silenced = 0;
 	}
 	share->state = state;
@@ -1183,7 +1203,7 @@ static int snd_pcm_share_drain(snd_pcm_t *pcm)
 			_snd_pcm_share_update(pcm);
 			Pthread_mutex_unlock(&slave->mutex);
 			if (!(pcm->mode & SND_PCM_NONBLOCK))
-				snd_pcm_wait(pcm, -1);
+				snd_pcm_wait(pcm, SND_PCM_WAIT_DRAIN);
 			return 0;
 		default:
 			assert(0);
@@ -1242,7 +1262,7 @@ static int snd_pcm_share_drop(snd_pcm_t *pcm)
 		assert(0);
 		break;
 	}
-	
+
 	share->appl_ptr = share->hw_ptr = 0;
  _end:
 	Pthread_mutex_unlock(&slave->mutex);
@@ -1388,11 +1408,11 @@ int snd_pcm_share_open(snd_pcm_t **pcmp, const char *name, const char *sname,
 
 	for (k = 0; k < channels; ++k) {
 		if (channels_map[k] >= sizeof(slave_map) / sizeof(slave_map[0])) {
-			SNDERR("Invalid slave channel (%d) in binding", channels_map[k]);
+			snd_error(PCM, "Invalid slave channel (%d) in binding", channels_map[k]);
 			return -EINVAL;
 		}
 		if (slave_map[channels_map[k]]) {
-			SNDERR("Repeated slave channel (%d) in binding", channels_map[k]);
+			snd_error(PCM, "Repeated slave channel (%d) in binding", channels_map[k]);
 			return -EINVAL;
 		}
 		slave_map[channels_map[k]] = 1;
@@ -1424,7 +1444,7 @@ int snd_pcm_share_open(snd_pcm_t **pcmp, const char *name, const char *sname,
 		free(share);
 		return -errno;
 	}
-		
+
 	if (stream == SND_PCM_STREAM_PLAYBACK) {
 		int bufsize = 1;
 		err = setsockopt(sd[0], SOL_SOCKET, SO_SNDBUF, &bufsize, sizeof(bufsize));
@@ -1433,7 +1453,7 @@ int snd_pcm_share_open(snd_pcm_t **pcmp, const char *name, const char *sname,
 			pfd.fd = sd[0];
 			pfd.events = POLLOUT;
 			while ((err = poll(&pfd, 1, 0)) == 1) {
-				char buf[1];
+				char buf[1] = {0};
 				err = write(sd[0], buf, 1);
 				assert(err != 0);
 				if (err != 1)
@@ -1505,7 +1525,7 @@ int snd_pcm_share_open(snd_pcm_t **pcmp, const char *name, const char *sname,
 			snd_pcm_share_t *sh = list_entry(i, snd_pcm_share_t, list);
 			for (k = 0; k < sh->channels; ++k) {
 				if (slave_map[sh->slave_channels[k]]) {
-					SNDERR("Slave channel %d is already in use", sh->slave_channels[k]);
+					snd_error(PCM, "Slave channel %d is already in use", sh->slave_channels[k]);
 					Pthread_mutex_unlock(&slave->mutex);
 					close(sd[0]);
 					close(sd[1]);
@@ -1522,7 +1542,7 @@ int snd_pcm_share_open(snd_pcm_t **pcmp, const char *name, const char *sname,
 	share->pcm = pcm;
 	share->client_socket = sd[0];
 	share->slave_socket = sd[1];
-	
+
 	pcm->mmap_rw = 1;
 	pcm->ops = &snd_pcm_share_ops;
 	pcm->fast_ops = &snd_pcm_share_fast_ops;
@@ -1558,17 +1578,17 @@ doesn't need the explicit server but access to the shared buffer.
 
 \code
 pcm.name {
-        type share              # Share PCM
-        slave STR               # Slave name
-        # or
-        slave {                 # Slave definition
-                pcm STR         # Slave PCM name
-                [format STR]    # Slave format
-                [channels INT]  # Slave channels
-                [rate INT]      # Slave rate
-                [period_time INT] # Slave period time in us
-                [buffer_time INT] # Slave buffer time in us
-        }
+	type share              # Share PCM
+	slave STR               # Slave name
+	# or
+	slave {                 # Slave definition
+		pcm STR         # Slave PCM name
+		[format STR]    # Slave format
+		[channels INT]  # Slave channels
+		[rate INT]      # Slave rate
+		[period_time INT] # Slave period time in us
+		[buffer_time INT] # Slave buffer time in us
+	}
 	bindings {
 		N INT		# Slave channel INT for client channel N
 	}
@@ -1613,7 +1633,7 @@ int _snd_pcm_share_open(snd_pcm_t **pcmp, const char *name,
 	int srate = -1;
 	int speriod_time= -1, sbuffer_time = -1;
 	unsigned int schannel_max = 0;
-	
+
 	snd_config_for_each(i, next, conf) {
 		snd_config_t *n = snd_config_iterator_entry(i);
 		const char *id;
@@ -1627,17 +1647,17 @@ int _snd_pcm_share_open(snd_pcm_t **pcmp, const char *name,
 		}
 		if (strcmp(id, "bindings") == 0) {
 			if (snd_config_get_type(n) != SND_CONFIG_TYPE_COMPOUND) {
-				SNDERR("Invalid type for %s", id);
+				snd_error(PCM, "Invalid type for %s", id);
 				return -EINVAL;
 			}
 			bindings = n;
 			continue;
 		}
-		SNDERR("Unknown field %s", id);
+		snd_error(PCM, "Unknown field %s", id);
 		return -EINVAL;
 	}
 	if (!slave) {
-		SNDERR("slave is not defined");
+		snd_error(PCM, "slave is not defined");
 		return -EINVAL;
 	}
 	err = snd_pcm_slave_conf(root, slave, &sconf, 5,
@@ -1654,12 +1674,12 @@ int _snd_pcm_share_open(snd_pcm_t **pcmp, const char *name,
 	sname = err >= 0 && sname ? strdup(sname) : NULL;
 	snd_config_delete(sconf);
 	if (sname == NULL) {
-		SNDERR("slave.pcm is not a string");
+		snd_error(PCM, "slave.pcm is not a string");
 		return err;
 	}
 
 	if (!bindings) {
-		SNDERR("bindings is not defined");
+		snd_error(PCM, "bindings is not defined");
 		err = -EINVAL;
 		goto _free;
 	}
@@ -1671,7 +1691,7 @@ int _snd_pcm_share_open(snd_pcm_t **pcmp, const char *name,
 			continue;
 		err = safe_strtol(id, &cchannel);
 		if (err < 0 || cchannel < 0) {
-			SNDERR("Invalid client channel in binding: %s", id);
+			snd_error(PCM, "Invalid client channel in binding: %s", id);
 			err = -EINVAL;
 			goto _free;
 		}
@@ -1679,7 +1699,7 @@ int _snd_pcm_share_open(snd_pcm_t **pcmp, const char *name,
 			channels = cchannel + 1;
 	}
 	if (channels == 0) {
-		SNDERR("No bindings defined");
+		snd_error(PCM, "No bindings defined");
 		err = -EINVAL;
 		goto _free;
 	}
@@ -1709,7 +1729,7 @@ int _snd_pcm_share_open(snd_pcm_t **pcmp, const char *name,
 	}
 	if (schannels <= 0)
 		schannels = schannel_max + 1;
-	err = snd_pcm_share_open(pcmp, name, sname, sformat, srate, 
+	err = snd_pcm_share_open(pcmp, name, sname, sformat, srate,
 				 (unsigned int) schannels,
 				 speriod_time, sbuffer_time,
 				 channels, channels_map, stream, mode);
