@@ -119,7 +119,7 @@ int snd_seq_delete_simple_port(snd_seq_t *seq, int port)
 int snd_seq_connect_from(snd_seq_t *seq, int myport, int src_client, int src_port)
 {
 	snd_seq_port_subscribe_t subs;
-	
+
 	memset(&subs, 0, sizeof(subs));
 	subs.sender.client = src_client;
 	subs.sender.port = src_port;
@@ -146,7 +146,7 @@ int snd_seq_connect_from(snd_seq_t *seq, int myport, int src_client, int src_por
 int snd_seq_connect_to(snd_seq_t *seq, int myport, int dest_client, int dest_port)
 {
 	snd_seq_port_subscribe_t subs;
-	
+
 	memset(&subs, 0, sizeof(subs));
 	/*subs.sender.client = seq->client;*/
 	subs.sender.client = snd_seq_client_id(seq);
@@ -173,7 +173,7 @@ int snd_seq_connect_to(snd_seq_t *seq, int myport, int dest_client, int dest_por
 int snd_seq_disconnect_from(snd_seq_t *seq, int myport, int src_client, int src_port)
 {
 	snd_seq_port_subscribe_t subs;
-	
+
 	memset(&subs, 0, sizeof(subs));
 	subs.sender.client = src_client;
 	subs.sender.port = src_port;
@@ -200,7 +200,7 @@ int snd_seq_disconnect_from(snd_seq_t *seq, int myport, int src_client, int src_
 int snd_seq_disconnect_to(snd_seq_t *seq, int myport, int dest_client, int dest_port)
 {
 	snd_seq_port_subscribe_t subs;
-	
+
 	memset(&subs, 0, sizeof(subs));
 	/*subs.sender.client = seq->client;*/
 	subs.sender.client = snd_seq_client_id(seq);
@@ -400,7 +400,7 @@ int snd_seq_sync_output_queue(snd_seq_t *seq)
 	pfd.fd = seq->poll_fd;
 	pfd.events = POLLOUT;
 	err = poll(&pfd, 1, -1);
-	/* restore the room size */ 
+	/* restore the room size */
 	info.output_room = saved_room;
 	snd_seq_set_client_pool(seq, &info);
 	return err;
@@ -476,6 +476,8 @@ int snd_seq_parse_address(snd_seq_t *seq, snd_seq_addr_t *addr, const char *arg)
 			if (!strncmp(arg, cinfo.name, len)) {
 				if (strlen(cinfo.name) == (size_t)len) {
 					/* exact match */
+					if (cinfo.client < 0)
+						return -EIO;
 					addr->client = cinfo.client;
 					return 0;
 				}
@@ -525,7 +527,7 @@ int snd_seq_create_ump_endpoint(snd_seq_t *seq,
 		return -EINVAL;
 
 	if (!(info->protocol_caps & info->protocol)) {
-		SNDERR("Inconsistent UMP protocol_caps and protocol\n");
+		snd_error(SEQUENCER, "Inconsistent UMP protocol_caps and protocol\n");
 		return -EINVAL;
 	}
 
@@ -534,13 +536,13 @@ int snd_seq_create_ump_endpoint(snd_seq_t *seq,
 	} else if (info->protocol & SND_UMP_EP_INFO_PROTO_MIDI1) {
 		version = SND_SEQ_CLIENT_UMP_MIDI_1_0;
 	} else {
-		SNDERR("Invalid UMP protocol set 0x%x\n", info->protocol);
+		snd_error(SEQUENCER, "Invalid UMP protocol set 0x%x\n", info->protocol);
 		return -EINVAL;
 	}
 
 	err = snd_seq_set_client_midi_version(seq, version);
 	if (err < 0) {
-		SNDERR("Failed to set to MIDI protocol 0x%x\n", version);
+		snd_error(SEQUENCER, "Failed to set to MIDI protocol 0x%x\n", version);
 		return err;
 	}
 
@@ -560,7 +562,7 @@ int snd_seq_create_ump_endpoint(snd_seq_t *seq,
 
 	err = snd_seq_set_ump_endpoint_info(seq, seq->ump_ep);
 	if (err < 0) {
-		SNDERR("Failed to set UMP EP info\n");
+		snd_error(SEQUENCER, "Failed to set UMP EP info\n");
 		goto error_free;
 	}
 
@@ -586,7 +588,7 @@ int snd_seq_create_ump_endpoint(snd_seq_t *seq,
 	snd_seq_port_info_set_ump_group(pinfo, 0);
 	err = snd_seq_create_port(seq, pinfo);
 	if (err < 0) {
-		SNDERR("Failed to create MIDI 2.0 port\n");
+		snd_error(SEQUENCER, "Failed to create MIDI 2.0 port\n");
 		goto error_free;
 	}
 
@@ -601,7 +603,7 @@ int snd_seq_create_ump_endpoint(snd_seq_t *seq,
 		snd_seq_port_info_set_ump_group(pinfo, i + 1);
 		err = snd_seq_create_port(seq, pinfo);
 		if (err < 0) {
-			SNDERR("Failed to create Group port %d\n", i + 1);
+			snd_error(SEQUENCER, "Failed to create Group port %d\n", i + 1);
 			goto error;
 		}
 	}
@@ -725,7 +727,7 @@ int snd_seq_create_ump_block(snd_seq_t *seq, int blkid,
 
 	err = snd_seq_set_ump_block_info(seq, blkid, bp);
 	if (err < 0) {
-		SNDERR("Failed to set UMP EP info\n");
+		snd_error(SEQUENCER, "Failed to set UMP EP info\n");
 		free(bp);
 		seq->ump_blks[blkid] = NULL;
 		return err;
